'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.matches = exports.getMessage = exports.checkHtmlElement = undefined;

var _jestMatcherUtils = require('jest-matcher-utils');

function getDisplayName(subject) {
  if (subject && subject.constructor) {
    return subject.constructor.name;
  } else {
    return typeof subject;
  }
}

function checkHtmlElement(htmlElement) {
  if (!(htmlElement instanceof HTMLElement)) {
    throw new Error(`The given subject is a ${getDisplayName(htmlElement)}, not an HTMLElement`);
  }
}

function getMessage(matcher, expectedLabel, expectedValue, receivedLabel, receivedValue) {
  return [`${matcher}\n`, `${expectedLabel}:\n  ${(0, _jestMatcherUtils.EXPECTED_COLOR)(expectedValue)}`, `${receivedLabel}:\n  ${(0, _jestMatcherUtils.RECEIVED_COLOR)(receivedValue)}`].join('\n');
}

function matches(textToMatch, node, matcher) {
  if (typeof matcher === 'string') {
    return textToMatch.toLowerCase().includes(matcher.toLowerCase());
  } else {
    return matcher.test(textToMatch);
  }
}

exports.checkHtmlElement = checkHtmlElement;
exports.getMessage = getMessage;
exports.matches = matches;